@@ -7,8 +7,8 @@ from typing import Any, Tuple
 import vegaapiclient as vac
 
 
-@pytest.fixture(scope='module')
-def tradingGRPC():
+@pytest.fixture(scope="module")
+def trading():
     """
     Provide a VegaTradingClient, connected to $GRPC_NODE.
     """
@@ -17,8 +17,8 @@ def tradingGRPC():
     return vac.VegaTradingClient(grpc_node)
 
 
-@pytest.fixture(scope='module')
-def tradingdataGRPC():
+@pytest.fixture(scope="module")
+def tradingdata():
     """
     Provide a VegaTradingDataClient, connected to $GRPC_NODE.
     """
@@ -27,27 +27,17 @@ def tradingdataGRPC():
     return vac.VegaTradingDataClient(grpc_node)
 
 
-@pytest.fixture(scope='module')
-def tradingREST():
+@pytest.fixture(scope="module")
+def faucetclient():
     """
-    Provide a VegaTradingClient, connected to $REST_NODE.
+    Provide a FaucetClient, connected to $FAUCETSERVER.
     """
-    rest_node = os.getenv("REST_NODE")
-    assert rest_node is not None and rest_node != ""
-    return vac.VegaTradingClient(rest_node)
+    faucetserver = os.getenv("FAUCETSERVER")
+    assert faucetserver is not None and faucetserver != ""
+    return vac.FaucetClient(faucetserver)
 
 
-@pytest.fixture(scope='module')
-def tradingdataREST():
-    """
-    Provide a VegaTradingDataClient, connected to $REST_NODE.
-    """
-    rest_node = os.getenv("REST_NODE")
-    assert rest_node is not None and rest_node != ""
-    return vac.VegaTradingDataClient(rest_node)
-
-
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def walletclient():
     """
     Provide a WalletClient, connected to $WALLETSERVER.
@@ -57,7 +47,7 @@ def walletclient():
     return vac.WalletClient(walletserver)
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def walletname() -> str:
     """
     Return a random wallet name.
@@ -66,30 +56,25 @@ def walletname() -> str:
     return "".join(random.choice(choices) for i in range(40))
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def walletpassphrase() -> str:
     """
     Return a random wallet passphrase, passing strength requirements.
     """
     return "".join(
-        "".join(
-            random.choice(req)
-            for i in range(5)
-        )
+        "".join(random.choice(req) for i in range(5))
         for req in [
             string.ascii_uppercase,
             string.ascii_lowercase,
             string.digits,
-            string.punctuation
+            string.punctuation,
         ]
     )
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def walletClientWalletKeypair(
-    walletclient,
-    walletname,
-    walletpassphrase
+    walletclient, walletname, walletpassphrase
 ) -> Tuple[Any, str, str, str]:
     """
     Provide a WalletClient that has had a wallet and keypair added.
