@@ -10,11 +10,11 @@ def random_metadata() -> List[Dict[str, str]]:
     return [
         {
             "key": "".join(
-                random.choice(string.ascii_uppercase)
-                for i in range(10)),
+                random.choice(string.ascii_uppercase) for i in range(10)
+            ),
             "value": "".join(
-                random.choice(string.ascii_lowercase)
-                for i in range(10))
+                random.choice(string.ascii_lowercase) for i in range(10)
+            ),
         }
     ]
 
@@ -76,8 +76,7 @@ def test_walletclient(
     j = r.json()
     assert "signedTx" in j, "Bad response: {}".format(j)
     signedTx = j["signedTx"]
-    assert signedTx["pubKey"] == k["pub"]
-    assert signedTx["data"] == tx
+    assert blob in base64.b64decode(signedTx["tx"])
     # TODO: check signature
 
     # Update key metadata
